@@ -1,5 +1,5 @@
 
-/*  $Header: /cvs/gnome/gcalctool/gcalctool/syntax_translation.c,v 1.12 2005/08/03 19:11:58 sampie Exp $
+/*  $Header: /cvs/gnome/gcalctool/gcalctool/syntax_translation.c,v 1.14 2005/09/19 14:26:24 richb Exp $
  *
  *  Copyright (c) 2004-2005 Sami Pietila
  *
@@ -21,7 +21,7 @@
 
 #include <stdio.h>
 #include <libintl.h>
-#include <malloc.h>
+#include <stdlib.h>
 #include <assert.h>
 #include <string.h>
 
@@ -53,6 +53,7 @@ static struct word {
   { /* Integer part of a decimal number */       N_("int")   },
   { /* Natural logarithm */                      N_("ln")    },
   { /* Logarithm with 10 as a base number */     N_("log")   },
+  { /* Modulus */                                N_("mod")   },
   { /* Bitwise NOT */                            N_("not")   },
   { /* Bitwise OR */                             N_("or")    },
   { /* PI */                                     N_("pi")    },
